PdfLinkPrompt typedef

PdfLinkPrompt = Future<PdfLinkTarget?> Function(BuildContext context, {required int currentPage, String initialUrl, required int pageCount})

Supplies the target for a link the link tool (PdfEditTool.link) or the text-selection "Add link" action is placing. Return null to cancel. pageCount is the document's page count and currentPage the zero-based page the link is being drawn on (a sensible default for an internal jump).

Implementation

typedef PdfLinkPrompt = Future<PdfLinkTarget?> Function(
  BuildContext context, {
  required int pageCount,
  required int currentPage,
  String initialUrl,
});