PdfMoveDragPreview class

A single-selection move drag's floating preview.

A page overlay reports this to the viewer so the artwork can paint above neighbouring pages during a cross-page drag.

Constructors

PdfMoveDragPreview({required int pageIndex, required Picture picture, required Rect from, required Rect to, required double scale})
const

Properties

from Rect
final
hashCode int
The hash code for this object.
no setterinherited
pageIndex int
final
picture Picture
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Page-raster to view scale (PdfPageGeometry.scale).
final
to Rect
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited