operator [] method

V? operator [](
  1. int page
)

The cached value for page, or null on a miss. A hit is marked most-recently used so a lookup protects the entry from eviction.

Implementation

V? operator [](int page) {
  final hit = _entries.remove(page);
  if (hit == null) return null;
  _entries[page] = hit;
  return hit;
}