PdfScrollbarMarker class

A labelled location on a PdfScrollbar track.

Constructors

PdfScrollbarMarker({required double position, required String label, VoidCallback? onTap})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Tooltip and accessibility label (normally an outline title).
final
onTap VoidCallback?
Invoked when the tick is activated.
final
position double
Location along the document, normalized from 0 to 1.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited