onExportPages property
Receives the bytes of an exported page range, for the host to save. When given, an "Export pages…" entry appears in the page-actions footer menu.
Implementation
final void Function(Uint8List bytes)? onExportPages;
Receives the bytes of an exported page range, for the host to save. When given, an "Export pages…" entry appears in the page-actions footer menu.
final void Function(Uint8List bytes)? onExportPages;