SlugBatch class

Constructors

SlugBatch.fromData(SlugBatchData data)

Properties

atlas ↔ Image?
getter/setter pair
atlasHeight → int
final
atlasPixels → Uint8List
final
atlasWidth → int
final
cellHeight → double
final
chunks → List<Vertices>
final
hashCode → int
The hash code for this object.
no setterinherited
quadCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeAtlas() → Future<void>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited