SlugGlyphData class
Per-outline relocatable curve stream, memoized by outline identity.
Properties
- bandCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → double
-
final
- maxY → double
-
final
- minX → double
-
final
- minY → double
-
final
- overflow → bool
-
final
- qMinX → double
-
final
- qMinY → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → Uint8List?
-
final
- texelCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- totalBuildMicros ↔ int
-
getter/setter pair
- totalBuilds ↔ int
-
getter/setter pair
Static Methods
-
of(
PdfPath outline) → SlugGlyphData