debugNoShader property
Debug/benchmark: draw batches with a plain paint instead of the coverage shader (wrong output - quantifies the runtime-effect cost of software rasterization).
Implementation
static bool debugNoShader = false;
Debug/benchmark: draw batches with a plain paint instead of the coverage shader (wrong output - quantifies the runtime-effect cost of software rasterization).
static bool debugNoShader = false;