tolerance property
The flatten tolerance the strips were binned at (stripFlattenTolerance everywhere today; carried for the guard).
Implementation
final double tolerance;
The flatten tolerance the strips were binned at (stripFlattenTolerance everywhere today; carried for the guard).
final double tolerance;