finish method

StripPlan finish()

Runs the final flush point and packages the plan. Call exactly once, after every command has been replayed.

Implementation

StripPlan finish() {
  assert(!_finished, 'StripPlanBinner.finish() called twice');
  _finished = true;
  flushPending();
  return StripPlan(
    totalFlushPoints: flushPointCount,
    deviceWidth: deviceWidth,
    deviceHeight: deviceHeight,
    pageToDevice: pageToDevice,
    tolerance: stripFlattenTolerance,
    batches: batches,
    slugGlyphs: slugGlyphs,
    slugBatches: slugBatches,
    slugQuadCount: slugQuadCount,
    slugFallbackOutlineRuns: slugFallbackOutlineRuns,
    slugFallbackOrdinals: slugFallbackOrdinals,
  );
}