PdfAnnotationTapDetails class
Information about a PDF annotation tap.
Constructors
- PdfAnnotationTapDetails({required PdfAnnotation annotation, required int pageIndex, required Offset pagePoint, required Offset pageViewPosition, required Offset globalPosition})
-
const
Properties
- annotation → PdfAnnotation
-
The annotation hit by the tap.
final
- globalPosition → Offset
-
Tap location in global Flutter coordinates.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageIndex → int
-
Zero-based page index containing annotation.
final
- pagePoint → Offset
-
Tap location in PDF page coordinates, in points.
final
- pageViewPosition → Offset
-
Tap location in the displayed page widget's local coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited