PdfStampDateFormat enum
Date formats used by the built-in {{date}} and {{datetime}} stamp
template fields.
Values
- iso → const PdfStampDateFormat
- dayMonthYear → const PdfStampDateFormat
- monthDayYear → const PdfStampDateFormat
- dayMonthNameYear → const PdfStampDateFormat
- monthNameDayYear → const PdfStampDateFormat
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
DateTime value, {String? localeName}) → String -
Formats
valuefor the stamp{{date}}field. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PdfStampDateFormat> - A constant List of the values in this enum, in order of their declaration.