SlugChunkData class
One drawVertices-sized slice of a Slug batch.
Constructors
- SlugChunkData(Float32List positions, Float32List textureCoordinates, Int32List colors, Uint16List indices)
Properties
- colors → Int32List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indices → Uint16List
-
final
- positions → Float32List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textureCoordinates → Float32List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited