of static method
Snapshots strips (the generator reuses its buffers, so all data is
copied) into draw-ready form, or null when the buffer is empty.
Implementation
static StripBatch? of(StripBuffer strips) {
final data = StripBatchData.of(strips, 0);
return data == null ? null : StripBatch.fromData(data);
}